@@ -1,4 +1,8 @@
 test_that("it should test http download without cache", {
+  if (!covr::in_covr()) {
+    skip_on_cran()
+    skip_if_offline()
+  }
   url <- "https://olinda.bcb.gov.br/olinda/servico/PTAX/versao/v1/odata/Moedas"
   op <- options(rbcb_cache = FALSE)
   withr::defer(options(op))
@@ -6,6 +10,10 @@ test_that("it should test http download without cache", {
 })
 
 test_that("it should test http download with cache", {
+  if (!covr::in_covr()) {
+    skip_on_cran()
+    skip_if_offline()
+  }
   url <- "https://olinda.bcb.gov.br/olinda/servico/PTAX/versao/v1/odata/Moedas"
   op <- options(rbcb_cache = TRUE)
   withr::defer(options(op))
